ScrollBuilder constructor

ScrollBuilder(
  1. Widget child
)

Creates a ScrollBuilder with the given child.

The child will be wrapped in a scrollable widget when build is called, according to the overflow configuration set.

Implementation

ScrollBuilder(this.child);