TextBuilder constructor
TextBuilder(
- String text
Creates a TextBuilder with the given text.
The text will be displayed in a Text widget when build is called.
Implementation
TextBuilder(this.text);
Creates a TextBuilder with the given text.
The text will be displayed in a Text widget when build is called.
TextBuilder(this.text);